﻿using System;
using System.Collections.Generic;
using EnvelopeCreatorProject.DocusignAPI;
using EnvelopeCreatorProject.Exceptions;
using EnvelopeCreatorProject.Models.Signers;

namespace EnvelopeCreatorProject.Models.Recipients.RecipientTypeBuilders
{
    internal class InPersonSignersBuilder : SignerRecipientsBuilder
    {
        private readonly HostSigner _host;

        internal InPersonSignersBuilder(List<Tab> signTabs, List<Tab> initialsTabs, List<Tab> dataSignFields, HostSigner host)
            : base(signTabs, initialsTabs, dataSignFields)
        {
            _host = host;
        }

        protected override string GetData(Recipient objRecipient)
        {
            if (_host == null || string.IsNullOrEmpty(_host.HostEmail) || string.IsNullOrEmpty(_host.HostName))
                throw new SignerHostNullException();

            return string.Format("{{{0},{1},{2}}}",
                GetRecipientInPersonInfo(objRecipient),
                GetSignatureInfoTo(objRecipient),
                GetSignTabs(objRecipient)
                );
        }

        private string GetRecipientInPersonInfo(Recipient recipient)
        {
            return string.Format(
                  "{0}hostEmail{0}:{0}{1}{0},{0}hostName{0}:{0}{2}{0},{0}signerName{0}:{0}{3}{0},{0}signerEmail{0}:{0}{4}{0},{0}roleName{0}:{0}{5}{0},{6}",
                  "\"",
                  _host.HostEmail,
                  _host.HostName,
                  recipient.UserName,
                  recipient.Email,
                  recipient.RoleName,
                  GetRecipientCommonInfo(recipient)
                  );
        }

        internal override string GetRecipientsData()
        {
            return "\"inPersonSigners\":[" + base.GetRecipientsData() + "]";
        }

    }
}
